==> kubernetes-model-4.6.3-sources.jar: io/fabric8/openshift/api/model/OpenshiftRoleBindingListFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ListMetaFluentImpl;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class OpenshiftRoleBindingListFluentImpl<A extends OpenshiftRoleBindingListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements OpenshiftRoleBindingListFluent<A>{

    private String apiVersion;
    private List<OpenshiftRoleBindingBuilder> items;
    private String kind;
    private ListMetaBuilder metadata;

    public OpenshiftRoleBindingListFluentImpl(){
    }
    public OpenshiftRoleBindingListFluentImpl(OpenshiftRoleBindingList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,OpenshiftRoleBinding item){
            if (this.items == null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>();}
            OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,OpenshiftRoleBinding item){
            if (this.items == null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>();}
            OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(OpenshiftRoleBinding... items){
            if (this.items == null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>();}
            for (OpenshiftRoleBinding item : items) {OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<OpenshiftRoleBinding> items){
            if (this.items == null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>();}
            for (OpenshiftRoleBinding item : items) {OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(OpenshiftRoleBinding... items){
            for (OpenshiftRoleBinding item : items) {OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<OpenshiftRoleBinding> items){
            for (OpenshiftRoleBinding item : items) {OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<OpenshiftRoleBinding> getItems(){
            return build(items);
    }

    public List<OpenshiftRoleBinding> buildItems(){
            return build(items);
    }

    public OpenshiftRoleBinding buildItem(int index){
            return this.items.get(index).build();
    }

    public OpenshiftRoleBinding buildFirstItem(){
            return this.items.get(0).build();
    }

    public OpenshiftRoleBinding buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public OpenshiftRoleBinding buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OpenshiftRoleBindingBuilder> predicate){
            for (OpenshiftRoleBindingBuilder item: items) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OpenshiftRoleBindingBuilder> predicate){
            for (OpenshiftRoleBindingBuilder item: items) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withItems(List<OpenshiftRoleBinding> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>(); for (OpenshiftRoleBinding item : items){this.addToItems(item);}} else { this.items = new ArrayList<OpenshiftRoleBindingBuilder>();} return (A) this;
    }

    public A withItems(OpenshiftRoleBinding... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (OpenshiftRoleBinding item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> addNewItemLike(OpenshiftRoleBinding item){
            return new ItemsNestedImpl(-1, item);
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> setNewItemLike(int index,OpenshiftRoleBinding item){
            return new ItemsNestedImpl(index, item);
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OpenshiftRoleBindingBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ListMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ListMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ListMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item){
            return new MetadataNestedImpl(item);
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ListMetaBuilder().build());
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            OpenshiftRoleBindingListFluentImpl that = (OpenshiftRoleBindingListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends OpenshiftRoleBindingFluentImpl<OpenshiftRoleBindingListFluent.ItemsNested<N>> implements OpenshiftRoleBindingListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final OpenshiftRoleBindingBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,OpenshiftRoleBinding item){
                    this.index = index;
                    this.builder = new OpenshiftRoleBindingBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new OpenshiftRoleBindingBuilder(this);
            }
    
    public N and(){
            return (N) OpenshiftRoleBindingListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}
    public class MetadataNestedImpl<N> extends ListMetaFluentImpl<OpenshiftRoleBindingListFluent.MetadataNested<N>> implements OpenshiftRoleBindingListFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ListMetaBuilder builder;
    
            MetadataNestedImpl(ListMeta item){
                    this.builder = new ListMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ListMetaBuilder(this);
            }
    
    public N and(){
            return (N) OpenshiftRoleBindingListFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}


}

==> kubernetes-model-4.7.0-sources.jar: io/fabric8/openshift/api/model/OpenshiftRoleBindingListFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ListMetaFluentImpl;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class OpenshiftRoleBindingListFluentImpl<A extends OpenshiftRoleBindingListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements OpenshiftRoleBindingListFluent<A>{

    private String apiVersion;
    private List<OpenshiftRoleBindingBuilder> items =  new ArrayList<OpenshiftRoleBindingBuilder>();
    private String kind;
    private ListMetaBuilder metadata;

    public OpenshiftRoleBindingListFluentImpl(){
    }
    public OpenshiftRoleBindingListFluentImpl(OpenshiftRoleBindingList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,OpenshiftRoleBinding item){
            if (this.items == null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>();}
            OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,OpenshiftRoleBinding item){
            if (this.items == null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>();}
            OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(OpenshiftRoleBinding... items){
            if (this.items == null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>();}
            for (OpenshiftRoleBinding item : items) {OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<OpenshiftRoleBinding> items){
            if (this.items == null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>();}
            for (OpenshiftRoleBinding item : items) {OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(OpenshiftRoleBinding... items){
            for (OpenshiftRoleBinding item : items) {OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<OpenshiftRoleBinding> items){
            for (OpenshiftRoleBinding item : items) {OpenshiftRoleBindingBuilder builder = new OpenshiftRoleBindingBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<OpenshiftRoleBindingBuilder> predicate){
            if (items == null) return (A) this;
            final Iterator<OpenshiftRoleBindingBuilder> each = items.iterator();
            final List visitables = _visitables.get("items");
            while (each.hasNext()) {
              OpenshiftRoleBindingBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<OpenshiftRoleBinding> getItems(){
            return build(items);
    }

    public List<OpenshiftRoleBinding> buildItems(){
            return build(items);
    }

    public OpenshiftRoleBinding buildItem(int index){
            return this.items.get(index).build();
    }

    public OpenshiftRoleBinding buildFirstItem(){
            return this.items.get(0).build();
    }

    public OpenshiftRoleBinding buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public OpenshiftRoleBinding buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OpenshiftRoleBindingBuilder> predicate){
            for (OpenshiftRoleBindingBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OpenshiftRoleBindingBuilder> predicate){
            for (OpenshiftRoleBindingBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(List<OpenshiftRoleBinding> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<OpenshiftRoleBindingBuilder>(); for (OpenshiftRoleBinding item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(OpenshiftRoleBinding... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (OpenshiftRoleBinding item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> addNewItemLike(OpenshiftRoleBinding item){
            return new ItemsNestedImpl(-1, item);
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> setNewItemLike(int index,OpenshiftRoleBinding item){
            return new ItemsNestedImpl(index, item);
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public OpenshiftRoleBindingListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OpenshiftRoleBindingBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ListMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ListMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ListMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item){
            return new MetadataNestedImpl(item);
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ListMetaBuilder().build());
    }

    public OpenshiftRoleBindingListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            OpenshiftRoleBindingListFluentImpl that = (OpenshiftRoleBindingListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends OpenshiftRoleBindingFluentImpl<OpenshiftRoleBindingListFluent.ItemsNested<N>> implements OpenshiftRoleBindingListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final OpenshiftRoleBindingBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,OpenshiftRoleBinding item){
                    this.index = index;
                    this.builder = new OpenshiftRoleBindingBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new OpenshiftRoleBindingBuilder(this);
            }
    
    public N and(){
            return (N) OpenshiftRoleBindingListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem(){
            return and();
    }

}
    public class MetadataNestedImpl<N> extends ListMetaFluentImpl<OpenshiftRoleBindingListFluent.MetadataNested<N>> implements OpenshiftRoleBindingListFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ListMetaBuilder builder;
    
            MetadataNestedImpl(ListMeta item){
                    this.builder = new ListMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ListMetaBuilder(this);
            }
    
    public N and(){
            return (N) OpenshiftRoleBindingListFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}


}
